comprehensive_dropdown library

Classes

CDropdownMenu<T>
A dropdown menu that can be opened from a TextField. The selected menu item is displayed in that field.
CMenuEntry<T>
Defines a CDropdownMenu menu button that represents one item view in the menu.

Properties

actionBTN String
getter/setter pair

Typedefs

SearchCallback<T> = int? Function(List<CMenuEntry<T>> entries, String query)
A callback function that returns the index of the item that matches the current contents of a text field.