SearchCallback<T> typedef
SearchCallback<T> =
int? Function(List<CMenuEntry<T> > entries, String query)
A callback function that returns the index of the item that matches the current contents of a text field.
If a match doesn't exist then null must be returned.
Used by CDropdownMenu.searchCallback.
Implementation
typedef SearchCallback<T> = int? Function(
List<CMenuEntry<T>> entries, String query);